Change Log
===========

0.3.1
------
* Restore self.my_send for sendp: my_send uses L3Socket, my_send L2Socket
* conf.checkIPaddr does not have effect
* Remove forgotten GPL license text
* Add changelog
* Fix travis style and dependencies for documentation
* Fix running documentation

0.3.0
------

Multiple changes and refactoring.

* Python 3 compatible
* Add tests
* Improve docstrings
* Update documentation and diagrams


v0.1.8.2
---------
